# A collection of ListItems primarily to be used within a ListView

[pub-package](https://pub.dartlang.org/packages/slick_list_items)

[author](https://twitter.com/imujtaba8488)

## Description

This package contains a number of slick and adaptable list items that are primarily to
be used within ListViews

## Using

Simply import package: slick_list_items/slick_list_items.dart and choose one or
all from the following:-

* **FlatListItem:** A FlatListItem is typically added to a ListView to display textual information. A FlatListItems is divided into three columns, wherein, first one on the left displays an icon, the second and the third columns both have 2 rows. The first row displays the label of the data it represents and the second row displays the data itself. Columns may be separted using a hanging divider in a FlatListItem.
* **BrickListItem:** A BrickListItem is created on the analogy of a wall and bricks. The container that holds all the widgets is called a 'wall' and the individual widgets within the wall are called as 'bricks'. When bricks are added to the wall they automatically resize and position themselves to fit the wall. It also allows for nesting, i.e. you can nest BrickListItems within one another.

## Using FlatListItem

```dart
class TransactionsList extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return ListView.builder(
      itemBuilder: _buildList,
    );
  }

  Widget _buildList(BuildContext context, int index) {
    return FlatListItem.transparent(
      context: context,
      scalePreset: ScalePreset.minimal,
      icon: Icon(Icons.monetization_on, color: Colors.black,),
      leftLabelText: 'Amount',
      leftDataText: '0123456789',
      rightLabelText: 'Description',
      rightDataText: 'Bought grocery at...',
    );
  }
}
```

## Using BrickListItem

```dart
import 'package:flutter/material.dart';

import 'package:brick_list_items/brick_list_item.dart';

class TestPage extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text('Widget Test'),
      ),
      body: ListView.builder(
        itemBuilder: _buildList,
      ),
    );
  }

  Widget _buildList(BuildContext context, int index) {
    return BrickListItem.ocean(
      widgets: <Widget>[
        Icon(
          Icons.android,
          color: Colors.black,
        ),
        Text(
          'BrickListItem',
          style: TextStyle(color: Colors.brown),
        ),
      ],
    );
  }
}
```

## Screenshots

![BrickListItem](<https://github.com/imujtaba8488/image_repo/blob/master/brick_list_item_img3>)
![BrickListItem](https://github.com/imujtaba8488/image_repo/blob/master/brick_list_item_img_1)
![BrickListItem](https://github.com/imujtaba8488/image_repo/blob/master/BrickListItem_img2)